@@ -1,21 +1,22 @@
 import json
 import logging
 import os
+
+import numpy as np
 import pandas as pd
 import requests
 from jsonschema import validate
 from jsonschema.exceptions import ValidationError
 
-
 import censius.utils as utils
 from censius.constants import *
 from censius.schemas import (
     batch_log_schema,
     bulk_log_schema,
+    explanations_tabular_schema,
     individual_log_schema,
     log_explanations_schema,
     prediction_tabular_schema,
-    explanations_tabular_schema,
     process_model_schema,
     register_dataset_schema,
     register_model_schema,
@@ -561,7 +562,8 @@ class CensiusClient(object):
             registered_dataset_to_datatype, registered_model_target = dict(), list()
             registered_dataset_to_datatype = registered_dataset_details["dataset_datatype"]
             registered_model_target = registered_dataset_details["model_target"]
-            model_target_col = registered_model_target[0].title()
+            model_target_col = registered_model_target[0]
+
             # remove model_target from registered_dataset_to_datatype
         else:
             return self.__return_message(response)
@@ -665,7 +667,8 @@ class CensiusClient(object):
             processed_input = input.rename(columns=input_map, inplace=False)
             # only keep the columns that are required for bulk logging
             processed_input = processed_input[list(input_map.values())]
-            processed_input = processed_input.where(pd.notnull(processed_input), None)
+            # processed_input = processed_input.where(pd.notnull(processed_input), None)
+            processed_input = processed_input.replace({np.nan: None})
 
             """
                 Call in bulk processing class to divide the dataframe into chunks and process.
