@@ -15,7 +15,8 @@ LOG_URL = lambda: f"{BASE_URL}/logs"
 UPDATE_ACTUAL_URL = lambda prediction_id: f"{BASE_URL}/logs/{prediction_id}/updateActual"
 BULK_LOG_DATATYPE_VALIDATION_URL = f"{BASE_URL}/logs/validate_bulk_datatype"
 BULK_LOG_URL = f"{BASE_URL}/logs/bulk_logs"
-
+LOG_EXPLAINATIONS_URL = lambda: f"{BASE_URL}/explainations"
+BULK_EXPLAINATIONS_URL = f"{BASE_URL}/explainations/bulk_explainations"
 
 # Dataset
 REGISTER_DATASET_URL = lambda: f"{AMS_URL}/datasets/register"
